**Example 1: 请求示例**

请求示例

Input: 

```
tccli cfw ModifyNatInstance --cli-unfold-argument  \
    --InstanceName [autotest]【勿动】自动化测试-123 \
    --NatInstanceId cfwnat-f0f1c7c0
```

Output: 
```
{
    "Response": {
        "NatInstanceId": "cfwnat-f0f1c7c0",
        "RequestId": "2cc7814e-fb74-479b-8995-41eb3b712930",
        "Status": 0
    }
}
```

